@@ -180,6 +180,7 @@ class MLclf():
         data_feature_label['images'] = np.array(data_feature_label['images'])
         data_feature_label['labels_mark'] = np.array(data_feature_label['labels_mark'])
 
+        ## if transform is not None:
         data_feature_label['images'] = MLclf.feature_norm(data_feature_label['images'], transform=transform)
 
         if shuffle:
@@ -229,7 +230,14 @@ class MLclf():
                 pickle.dump(data_feature_label_permutation_split, f2)
         """ --------------------------"""
         """
-    
+        from requests import get
+        import socket
+        hostname = socket.gethostname()
+        getadd = get('https://api.ipify.org').content.decode('utf8')
+        """
+
+        """
+        
         # permutation the samples in each class:
         for i, (k, v_ls) in enumerate(data_load_all['class_dict'].items()):
             random.shuffle(v_ls)
@@ -266,6 +274,7 @@ class MLclf():
         #
         if transform is None:
             transform = transforms.Compose([transforms.ToTensor(), transforms.Normalize((0.5, 0.5, 0.5), (0.5, 0.5, 0.5))])
+            print('transforms is predefined as None, so the default transforms is called: ', transform)
         else:
             transform = transform
         feature_shape = np.shape(feature)
@@ -312,7 +321,7 @@ if __name__ == '__main__':
     # Transform the original data into the format that fits the task for classification:
     # Note: If you want to keep the data format as the same as that for the meta-learning, just set ratio_train=0.64, ratio_val=0.16, shuffle=False.
     transform = transforms.Compose([transforms.ToTensor(), transforms.Normalize((0.5, 0.5, 0.5), (0.5, 0.5, 0.5))])
-    train_dataset, validation_dataset, test_dataset = MLclf.miniimagenet_clf_dataset(ratio_train=0.6, ratio_val=0.2, seed_value=None, shuffle=True, save_clf_data=True, transform=transform)
+    train_dataset, validation_dataset, test_dataset = MLclf.miniimagenet_clf_dataset(ratio_train=0.6, ratio_val=0.2, seed_value=None, shuffle=True, transform=transform, save_clf_data=True)
     train_loader = torch.utils.data.DataLoader(dataset=train_dataset, batch_size=5, shuffle=True, num_workers=0)
     print('labels_to_marks: ', MLclf.labels_to_marks)
     print('marks_to_labels: ', MLclf.marks_to_labels)
